@@ -1,6 +1,9 @@
 import cobrakbase.core.kbasefba
+import cobrakbase.core.kbasebiochem
 import cobrakbase.core.kbasegenome
+import cobrakbase.core.kbasematrices
 from cobrakbase.core.model import KBaseFBAModel
 from cobrakbase.core.kbasebiochemmedia import KBaseBiochemMedia
 from cobrakbase.core.kbasefbafba import KBaseFBA
-from cobrakbase.core.kbasegenomesgenome import KBaseGenome
\ No newline at end of file
+from cobrakbase.core.kbasegenomesgenome import KBaseGenome
+from cobrakbase.core.build_metabolic_model import build_metabolic_model
