@@ -1,13 +1,12 @@
 class ModelSEEDObject:
-
     def __init__(self, data, api=None):
         self.data = data
         self.api = api
 
     @property
     def id(self):
-        return self.data['id']
+        return self.data["id"]
 
     @property
     def name(self):
-        return self.data['name']
+        return self.data["name"]
